sharddistributor

package
v1.3.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 24, 2025 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service represents the shard distributor service for legacy resource based initialization. DEPRECATED: use fx and sharddistributorfx to avoid creating start/stopper.

func NewService

func NewService(
	params *resource.Params,
	factory resource.ResourceFactory,
) (*Service, error)

NewService is an adapter for legacy initialization without fx.

func (*Service) Start

func (s *Service) Start()

Start legacy mode fx stops the component and ensures order/wait time between dependent components.

func (*Service) Stop

func (s *Service) Stop()

Stop legacy mode, fx stops the component and ensures order/wait time between dependent components.

Directories

Path Synopsis
Package executorclient is a generated GoMock package.
Package executorclient is a generated GoMock package.
Package handler is a generated GoMock package.
Package handler is a generated GoMock package.
leader
election
Package election is a generated GoMock package.
Package election is a generated GoMock package.
process
Package process is a generated GoMock package.
Package process is a generated GoMock package.
store/etcd module
Package store is a generated GoMock package.
Package store is a generated GoMock package.
etcd module
wrappers

Jump to