Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service represents the shard distributor service for legacy resource based initialization. DEPRECATED: use fx and sharddistributorfx to avoid creating start/stopper.
func NewService ¶
NewService is an adapter for legacy initialization without fx.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package executorclient is a generated GoMock package.
|
Package executorclient is a generated GoMock package. |
|
Package handler is a generated GoMock package.
|
Package handler is a generated GoMock package. |
|
leader
|
|
|
election
Package election is a generated GoMock package.
|
Package election is a generated GoMock package. |
|
process
Package process is a generated GoMock package.
|
Package process is a generated GoMock package. |
|
leaderstore/etcd
module
|
|
|
store/etcd
module
|
|
|
Package store is a generated GoMock package.
|
Package store is a generated GoMock package. |
|
etcd
module
|
|
|
wrappers
|
|
Click to show internal directories.
Click to hide internal directories.